<?php

declare(strict_types=1);

namespace App\Controller;

use App\JsonRpc\NewsServiceInterface;
use App\Tools\PublicData;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use Hyperf\Context\Context;
use App\JsonRpc\UserServiceInterface;
use App\JsonRpc\WebsiteServiceInterface;
use Laminas\Mime\Decode;

/**
 * Class NewsController
 * @package App\Controller
 */
//#[AutoController]
class NewsController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;

    /**
     * @var NewsServiceInterface
     */
    #[Inject]
    private $newsServiceClient;
    /**
     * @var WebsiteServiceInterface
     */
    #[Inject]
    private $websiteServiceClient;

    /**
     * @var UserServiceInterface
     */
    #[Inject]
    private $userServiceClient;
    /**
     * @var WebsiteServiceInterface
     */
    #[Inject]
    private $WebsiteServiceClient;


    /**
     * 导航池列表
     * @return void
     */
    public function getCategoryList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'pageSize' => 'required',

            ],
            [
                'page.required' => 'id不能为空',
                'pageSize.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getCategoryList($requireData);
        if ($result['code'] == 200) {
            return Result::success($result['data']);
        }
        return  Result::error($result['message']);
    }
    /**
     * 站点下的导航池
     * @return void
     */
    public function categoryList()
    {

        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'pid' => 'required'
            ],
            [
                'pid.required' => '父级ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['website_id'] = Context::get("SiteId");
        //获取用户信息
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        var_dump("用户信息：", $userInfo);
        $sszq = $userInfo['data']['sszq'];
        $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        //管理员看所有
        if ($type_id == 10000) {
            $result = $this->newsServiceClient->categoryList($requireData);
        } else {
            $requireData['sszq'] = $sszq;
            $result = $this->newsServiceClient->myCategoryList($requireData);
        }
        //        $rep = PublicData::buildMenuTree($result['data']);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 添加导航
     * @return array|void
     */
    public function addCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name' => 'required',
                'seo_title' => 'required',
                'seo_keywords' => 'required',
                'seo_description' => 'required',
            ],
            [
                'name.required' => '导航池名称不能为空',
                'seo_title.required' => 'seo标题名称不能为空',
                'seo_keywords.required' => 'seo关键词不能为空',
                'seo_description.required' => 'seo描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['pid'] = isset($requireData['pid_arr']) ? end($requireData['pid_arr']) : '';
        $requireData['pid_arr'] = isset($requireData['pid_arr']) ? json_encode($requireData['pid_arr']) : '';

        // $requireData['city_id'] = isset($requireData['city_arr_id'])?end($requireData['city_arr_id']):'';
        // $requireData['city_arr_id'] = isset($requireData['city_arr_id'])?json_encode($requireData['city_arr_id']):'';

        // $requireData['department_id'] = isset($requireData['department_arr_id'])?end($requireData['department_arr_id']):'';
        // $requireData['department_arr_id'] = isset($requireData['department_arr_id'])?json_encode($requireData['department_arr_id']):'';

        $result = $this->newsServiceClient->addCategory($requireData);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新导航池
     * @return array
     */
    public function updateCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'name' => 'required',
                'seo_title' => 'required',
                'seo_keywords' => 'required',
                'seo_description' => 'required',
            ],
            [
                'id.required' => 'ID不能为空',
                'name.required' => '栏目池名称不能为空',
                'seo_title.required' => 'seo标题名称不能为空',
                'seo_keywords.required' => 'seo关键词不能为空',
                'seo_description.required' => 'seo描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['pid'] = isset($requireData['pid_arr']) ? end($requireData['pid_arr']) : '';
        $requireData['pid_arr'] = isset($requireData['pid_arr']) ? json_encode($requireData['pid_arr']) : '';

        // $requireData['city_id'] = isset($requireData['city_arr_id'])?end($requireData['city_arr_id']):'';
        // $requireData['city_arr_id'] = isset($requireData['city_arr_id'])?json_encode($requireData['city_arr_id']):'';

        // $requireData['department_id'] = isset($requireData['department_arr_id'])?end($requireData['department_arr_id']):'';
        // $requireData['department_arr_id'] = isset($requireData['department_arr_id'])?json_encode($requireData['department_arr_id']):'';

        $result = $this->newsServiceClient->updateCategory($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除分类
     * @return array
     */
    public function delCategory()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',

            ],
            [
                'id.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->delCategory($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 资讯列表
     * @return void
     */
    public function getArticleList()
    {
        $requireData = $this->request->all();

        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'pageSize' => 'required',

            ],
            [
                'page.required' => 'id不能为空',
                'pageSize.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['website_id'] = Context::get("SiteId");
        //获取用户信息
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        var_dump("用户信息：", $userInfo);
        $sszq = $userInfo['data']['sszq'];
        //获取websiteid
        // $groupInfo = $this->WebsiteServiceClient->getWebsiteGroupInfo(['id' => $sszq]);
        // var_dump("groupInfo:",$groupInfo);
        // $sszqstr = implode(',',json_decode($groupInfo['data']['web_ids']));

        $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        $requireData['type_id'] = $type_id;
        $requireData['user_id'] = $user_id;


        var_dump("资讯：", $requireData);
        $result = $this->newsServiceClient->getArticleList($requireData);
        //1通过，2待审核，3待发 4,拒绝 5删除
        $statusList = [
            '0' => '待审核',
            '1' => '已发布',
            '2' => '待审核',
            '3' => '待发',
            '4' => '拒绝',
            '5' => '删除',
        ];
        if ($result['data']) {
            foreach ($result['data']['rows'] as $k => $v) {
                $result['data']['rows'][$k]['cat_arr_id'] = $v['cat_arr_id'] ? json_decode($v['cat_arr_id']) : [0];
                $result['data']['rows'][$k]['tag'] = $v['tag'] ? json_decode($v['tag']) : [];
                $result['data']['rows'][$k]['status_name'] = $statusList[$v['status']];
                $result['data']['rows'][$k]['level'] = (string)$v['level'];
                $result['data']['rows'][$k]['islink'] = isset($v['islink']) && $v['islink'] > 0 ? true : false;
            }
        }
        // $result = $this->newsServiceClient->getArticleList($requireData);

        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取导航池信息
     * @return void
     */
    public function getCategoryInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',

            ],
            [
                'id.required' => 'id不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getCategoryInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 添加分类
     * @return array|void
     */
    public function addArticle()
    {
        // $a = ['asdlk1', '2342345234', [1, '222222222222']];
        // var_dump(json_encode($a));
        // return '222';
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title' => 'required',
                'cat_arr_id' => 'required',
                'author' => 'required',

            ],
            [
                'title.required' => '标题不能为空',
                'cat_arr_id.required' => '导航池ID不能为空',
                'author.required' => '作者不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['catid'] = isset($requireData['cat_arr_id']) ? end($requireData['cat_arr_id']) : '';
        $requireData['cat_arr_id'] = isset($requireData['cat_arr_id']) ? json_encode($requireData['cat_arr_id']) : '';

        $loginIp = $this->request->getHeader('x-forwarded-for')[0] ?? $this->request->getHeader('x-real-ip')[0] ?? $this->request->getServerParams()['remote_addr'] ?? '0.0.0.0';
        $requireData['ip'] = $loginIp;

        //        $requireData['website_id'] = Context::get("SiteId");
        $requireData['admin_user_id'] = Context::get("UserId");

        $requireData['level'] = isset($requireData['level']) &&  $requireData['level'] ? $requireData['level'] : 0;
        $requireData['hits'] = isset($requireData['hits']) &&  $requireData['hits'] ? $requireData['hits'] : 0;
        $requireData['is_original'] = isset($requireData['is_original']) &&  $requireData['is_original'] ? $requireData['is_original'] : 0;
        $requireData['status'] = isset($requireData['status']) &&  $requireData['status'] ? $requireData['status'] : 0;
        //        var_dump("入参：",$requireData);
        $result = $this->newsServiceClient->addArticle($requireData);

        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新资讯
     * @return array
     */
    public function updateArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'title' => 'required',
                'cat_arr_id' => 'required',
                'author' => 'required',
            ],
            [
                'title.required' => '标题不能为空',
                'cat_arr_id.required' => '导航池ID不能为空',
                'author.required' => '作者不能为空',
                'id.required' => 'ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $requireData['catid'] = isset($requireData['cat_arr_id']) ? end($requireData['cat_arr_id']) : '';
        $requireData['cat_arr_id'] = isset($requireData['cat_arr_id']) ? json_encode($requireData['cat_arr_id']) : '';

        $result = $this->newsServiceClient->updateArticle($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 更新资讯状态
     * @return array
     */
    public function upArticleStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'status' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->upArticleStatus($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 删除分类
     * @return array
     */
    public function delArticle()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        //        $requireData['website_id'] = Context::get("SiteId");
        $result = $this->newsServiceClient->delArticle($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取资讯信息
     * @return array
     */
    public function  getArticleInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $result = $this->newsServiceClient->getArticleInfo($requireData);
        if ($result['code'] == 0) {
            return Result::error($result['message']);
        }
        $result['data']['cat_arr_id'] =  $result['data']['cat_arr_id'] ? json_decode($result['data']['cat_arr_id']) : [];
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取调查问卷列表
     * @return array
     */
    public function getSurveyList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'pageSize' => 'required',
            ],
            [
                'page.required' => '第几页不能为空',
                'pageSize.required' => '每页显示条数不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getSurveyList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 获取调查问卷详情
     * @return array
     */
    public function getSurveyInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'sur_id' => 'required'
            ],
            [
                'sur_id.required' => 'sur_id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getSurveyInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 检测导航池名称是否存在
     * @return array
     */
    public function  checkCategoryName()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name' => 'required',
            ],
            [
                'name.required' => 'name不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $result = $this->newsServiceClient->checkCategoryName($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    //20250226  产品列表
    public function getGoodList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'integer|required',
                'page_size' => 'integer|required',
            ],
            [
                'page.integer' => 'page必须是整型',
                'page_size.integer' => 'page_size必须是整型',
                'page.required' => 'page不能为空',
                'page_size.required' => 'page_size不能为空',

            ]
        );
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        var_dump("用户信息：", $userInfo);
        $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        $requireData['type_id'] = $type_id;
        $requireData['user_id'] = $user_id;

        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getGoodList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getGoodInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getGoodInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateGood()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(

            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateGood($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error(
            $result['message']
        );
    }
    public function addGood()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name' => 'required',
                //  'price'=> 'numeric',
                //  'min'=> 'numeric',
                //  'max'=> 'numeric',
                //  'hits  '=> 'numeric',
            ],
            [
                'name.required' => '产品名称不能为空',
                //  'price.required' => '产品价格不能为空',
                //  'price.numeric' => '价格必须是数字',
                //  'min.numeric' => 'min必须是数字',
                //  'max.numeric' => 'max须是数字',
                //  'hits.numeric' => '点击量必须是数字',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = context::get("UserId");
        $result = $this->newsServiceClient->addGood($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function delGood()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->delGood($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    //20250226  产品列表
    //20250306  求职
    public function getJobHuntingList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'page_size' => 'required',
            ],
            [
                'page.required' => 'page不能为空',
                'page_size.required' => 'page_size不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        $type_id = $userInfo['data']['type_id']; //'1:个人会员 2：政务会员 3：企业会员 4:调研员 10000：管理员 20000：游客（小程序）'
        $requireData['type_id'] = $type_id;
        $requireData['user_id'] = $user_id;
        $result = $this->newsServiceClient->getJobHuntingList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getJobHuntingInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getJobHuntingInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateJobHunting()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name' => 'required',
                'sexy' => 'required',
            ],
            [
                'name.required' => '姓名不能为空',
                'sexy.required' => '性别不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateJobHunting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function addJobHunting()
    {

        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'name' => 'required',
                'sexy' => 'required',
            ],
            [
                'name.required' => '姓名不能为空',
                'sexy.required' => '性别不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = context::get("UserId");
        $result = $this->newsServiceClient->addJobHunting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function delJobHunting()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->delJobHunting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getJobHuntingData()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getJobHuntingData($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    //20250306  求职
    //20250324  通知，公告，消息
    public function getMSG()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [],
            []
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        if ($userInfo['code'] != 200) {
            return Result::error($userInfo['message']);
        }
        $requireData['user_id'] = $user_id;
        $requireData['type_id'] = $userInfo['data']['type_id'];
        $result = $this->newsServiceClient->getMSG($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function addNotice()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'content' => 'required',
            ],
            [
                'content.required' => '内容不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = context::get("UserId");
        $result = $this->newsServiceClient->addNotice($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function deleteNotice()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->deleteNotice($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getNoticeList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'page_size' => 'required',
            ],
            [
                'page.required' => 'page不能为空',
                'page_size.required' => 'page_size不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        $requireData['user_id'] = $user_id;
        $requireData['type_id'] = $userInfo['data']['type_id'];
        $result = $this->newsServiceClient->getNoticeList($requireData);
        if ($result['code'] == 200) {
            return Result::success($result['data']);
        }
        return  Result::error($result['message']);
    }
    public function getNoticeInfo()
    {

        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getNoticeInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateNotice()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'content' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'content.required' => '内容不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateNotice($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }



    public function addComplaint()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'content' => 'required',
            ],
            [
                'content.required' => '内容不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = context::get("UserId");
        $result = $this->newsServiceClient->addComplaint($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function deleteComplaint()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->deleteComplaint($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getComplaintList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'page_size' => 'required',
            ],
            [
                'page.required' => 'page不能为空',
                'page_size.required' => 'page_size不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $user_id = Context::get("UserId");
        $userInfo = $this->userServiceClient->getUserInfo((int)$user_id);
        $requireData['user_id'] = $user_id;
        $requireData['type_id'] = $userInfo['data']['type_id'];
        $result = $this->newsServiceClient->getComplaintList($requireData);
        if ($result['code'] == 200) {
            return Result::success($result['data']);
        }
        return  Result::error($result['message']);
    }
    public function getComplaintInfo()
    {

        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getComplaintInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateComplaint()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'content' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'content.required' => '内容不能为空',

            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateComplaint($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getDUser()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                // 'page' => 'integer|required',
                // 'page_size' => 'integer|required',
                // 'checkout' => 'integer|required',
            ],
            [
                // 'page.integer' => 'page必须是整型',
                // 'page_size.integer' => 'page_size必须是整型',
                // 'page.required' => 'page不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->getDUser($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    //20250324  通知，公告，消息

    //   20250306    招聘
    /*
      *后端-招聘 搜索及获取职位
      * @return array
      */
    public function getJobRecruitingList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'integer|required',
                'page_size' => 'integer|required',
                'checkout' => 'integer|required',
            ],
            [
                'page.integer' => 'page必须是整型',
                'page_size.integer' => 'page_size必须是整型',
                'page.required' => 'page不能为空',
                'page_size.required' => 'page_size不能为空',
                'checkout.required' => 'checkout不能为空',
                'checkout.integer' => 'checkout必须是整型',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['website_id'] = Context::get("SiteId");
        $requireData['user_id'] = Context::get("UserId");
        // return Result::success($requireData);
        if (empty($requireData['website_id']) || empty($requireData['user_id'])) {
            return Result::error('参数错误');
        }
        $result = $this->newsServiceClient->getJobRecruitingList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 获取公司信息
    * @return array
    */
    public function getJobCompany()
    {
        $requireData = $this->request->all();
        $requireData['website_id'] = Context::get("SiteId");
        $requireData['user_id'] = Context::get("UserId");
        // return Result::success($requireData);
        if (empty($requireData['user_id'])) {
            return Result::error('参数错误');
        }
        $result = $this->newsServiceClient->getJobCompany($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 修改公司信息
    * @return array
    */
    public function upJobCompany()
    {
        $requireData = $this->request->all();
        $requireData['user_id'] = Context::get("UserId");
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'user_id' => 'required',
                'business_name' => 'required',
                'company_hy_id' => 'required|integer',
                'company_size' => 'required|integer',
                'introduction' => 'required',
                // 'real_name'=>'required',
                // 'mobile'=>'required|integer',
                'address_arr_id' => 'required',
                'address' => 'required',
            ],
            [
                'user_id.required' => '用户id不能为空',
                'business_name.required' => '公司名称不能为空',
                'company_hy_id.required' => '所属行业不能为空',
                'company_hy_id.integer' => '所属行业必须是整数',
                'company_size.required' => '公司规模不能为空',
                'company_size.integer' => '公司规模必须是整数',
                'introduction.required' => '公司简介不能为空',
                // 'real_name.required' => '联系人不能为空',
                // 'mobile.required' => '联系电话不能为空',
                // 'mobile.integer' => '联系电话必须是整数',
                'address_arr_id.required' => '公司地址不能为空',
                'address.required' => '公司详细地址不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['website_id'] = Context::get("SiteId");

        // return Result::success($requireData);
        if (empty($requireData['user_id'])) {
            return Result::error('参数错误');
        }
        $result = $this->newsServiceClient->upJobCompany($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 获取职位详情
    * @return array
    */
    public function getJobRecruitingInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required|integer',
            ],
            [
                'id.required' => 'id不能为空',
                'id.integer' => 'id必须是整数',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        // return Result::success($requireData);
        $requireData['website_id'] = Context::get("SiteId");
        $requireData['user_id'] = Context::get("UserId");
        // return Result::success($requireData);
        if (empty($requireData['user_id'])) {
            return Result::error('参数错误');
        }
        $result = $this->newsServiceClient->getJobRecruitingInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 新增职位
    * @return array
    */
    public function addJobRecruiting()
    {
        $requireData = $this->request->all();
        // 定义验证规则数组
        $jobValidationRules = [
            'title' => 'required',
            'cat_arr_id' => 'required',
            'city_arr_id' => 'required',
            'hy_id' => 'required|integer',
            'zw_id' => 'required|integer',
            'jtzw_id' => 'required|integer',
            'nature_id' => 'required|integer',
            'due_data' => 'required',
            'description' => 'required',
        ];
        // 定义验证错误信息数组
        $jobValidationMessages = [
            'title.required' => '职位名称不能为空',
            'cat_arr_id.required' => '栏目不能为空',
            'city_arr_id.required' => '工作地区不能为空',
            'hy_id.required' => '行业分类不能为空',
            'hy_id.integer' => '行业分类必须是整数',
            'zw_id.required' => '职位分类不能为空',
            'zw_id.integer' => '职位分类必须是整数',
            'jtzw_id.required' => '职位不能为空',
            'jtzw_id.integer' => '职位分类必须是整数',
            'nature_id.required' => '职位性质不能为空',
            'nature_id.integer' => '职位性质必须是整数',
            'due_data.required' => '截止日期不能为空',
            'description.required' => '职位描述不能为空',
        ];
        // 定义公司信息验证规则数组
        $companyValidationRules = [
            'website_id' => 'required|integer',
            'business_name' => 'required',
            'company_hy_id' => 'required|integer',
            'company_size' => 'required|integer',
            'company_nature' => 'required|integer',
            'introduction' => 'required',
            'real_name' => 'required',
            // 将联系电话的验证规则修改为最少十一位整数
            'mobile' => 'required|integer|min:10000000000',
            'address_arr_id' => 'required',
            'address' => 'required',
        ];
        // 定义公司信息验证错误信息数组
        $companyValidationMessages = [
            'website_id.required' => '网站ID不能为空',
            'website_id.integer' => '网站ID必须是整数',
            'business_name.required' => '公司名称不能为空',
            'company_hy_id.required' => '所属行业不能为空',
            'company_hy_id.integer' => '所属行业必须是整数',
            'company_size.required' => '公司规模不能为空',
            'company_size.integer' => '公司规模必须是整数',
            'company_nature.required' => '公司性质不能为空',
            'company_nature.integer' => '公司性质必须是整数',
            'introduction.required' => '公司简介不能为空',
            'real_name.required' => '联系人不能为空',
            'mobile.required' => '联系电话不能为空',
            'mobile.integer' => '联系电话必须是整数',
            'mobile.min' => '联系电话必须是11位',
            'address_arr_id.required' => '公司地址不能为空',
            'address.required' => '公司详细地址不能为空',
        ];
        if (!isset($requireData['user_type']) || $requireData['user_type'] === null) {
            return Result::error('参数错误');
        }

        switch ($requireData['user_type']) {
            case 3:
                $validator = $this->validationFactory->make($requireData, $jobValidationRules, $jobValidationMessages);
                if ($validator->fails()) {
                    return Result::error($validator->errors()->first());
                }
                $requireData['website_id'] = Context::get("SiteId") ?? 0;
                break;
            case 10000:
                $validator = $this->validationFactory->make($requireData, $jobValidationRules, $jobValidationMessages);
                if ($validator->fails()) {
                    return Result::error($validator->errors()->first());
                }
                $validator = $this->validationFactory->make($requireData, $companyValidationRules, $companyValidationMessages);
                if ($validator->fails()) {
                    return Result::error($validator->errors()->first());
                }
                // $requireData['website_id'] = Context::get("SiteId") ?? 0;
                break;
            default:
                return Result::error('不支持的用户类型');
        }
        $requireData['user_id'] = Context::get("UserId") ?? 0;
        $result = $this->newsServiceClient->addJobRecruiting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 修改职位
    * @return array
    */
    public function upJobRecruiting()
    {
        $requireData = $this->request->all();
        // 定义验证规则数组
        $jobValidationRules = [
            'title' => 'required',
            'cat_arr_id' => 'required',
            'city_arr_id' => 'required',
            'hy_id' => 'required|integer',
            'zw_id' => 'required|integer',
            'jtzw_id' => 'required|integer',
            'nature_id' => 'required|integer',
            'due_data' => 'required',
            'description' => 'required',
        ];
        // 定义验证错误信息数组
        $jobValidationMessages = [
            'title.required' => '职位名称不能为空',
            'cat_arr_id.required' => '栏目不能为空',
            'city_arr_id.required' => '工作地区不能为空',
            'hy_id.required' => '行业分类不能为空',
            'hy_id.integer' => '行业分类必须是整数',
            'zw_id.required' => '职位分类不能为空',
            'zw_id.integer' => '职位分类必须是整数',
            'jtzw_id.required' => '职位不能为空',
            'jtzw_id.integer' => '职位分类必须是整数',
            'nature_id.required' => '职位性质不能为空',
            'nature_id.integer' => '职位性质必须是整数',
            'due_data.required' => '截止日期不能为空',
            'description.required' => '职位描述不能为空',
        ];
        // 定义公司信息验证规则数组
        $companyValidationRules = [
            'business_name' => 'required',
            'company_hy_id' => 'required',
            'company_size' => 'required',
            'company_nature' => 'required',
            'introduction' => 'required',
            'real_name' => 'required',
            // 将联系电话的验证规则修改为最少十一位整数
            'mobile' => 'required|integer|min:10000000000',
            'address_arr_id' => 'required',
            'address' => 'required',
        ];
        // 定义公司信息验证错误信息数组
        $companyValidationMessages = [
            'business_name.required' => '公司名称不能为空',
            'company_hy_id.required' => '所属行业不能为空',
            'company_size.required' => '公司规模不能为空',
            'company_nature.required' => '公司性质不能为空',
            'introduction.required' => '公司简介不能为空',
            'real_name.required' => '联系人不能为空',
            'mobile.required' => '联系电话不能为空',
            'mobile.integer' => '联系电话必须是整数',
            'mobile.min' => '联系电话必须是11位',
            'address_arr_id.required' => '公司地址不能为空',
            'address.required' => '公司详细地址不能为空',
        ];
        if (!isset($requireData['user_type']) || $requireData['user_type'] === null) {
            return Result::error('参数错误');
        }

        switch ($requireData['user_type']) {
            case 3:
                $validator = $this->validationFactory->make($requireData, $jobValidationRules, $jobValidationMessages);
                if ($validator->fails()) {
                    return Result::error($validator->errors()->first());
                }
                $requireData['website_id'] = Context::get("SiteId") ?? 0;
                break;
            case 10000:
                $validator = $this->validationFactory->make($requireData, $jobValidationRules, $jobValidationMessages);
                if ($validator->fails()) {
                    return Result::error($validator->errors()->first());
                }
                $validator = $this->validationFactory->make($requireData, $companyValidationRules, $companyValidationMessages);
                if ($validator->fails()) {
                    return Result::error($validator->errors()->first());
                }
                // $requireData['website_id'] = Context::get("SiteId") ?? 0;
                break;
            default:
                return Result::error('不支持的用户类型');
        }
        $requireData['user_id'] = Context::get("UserId") ?? 0;
        // return Result::success($requireData);
        $result = $this->newsServiceClient->upJobRecruiting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 删除职位
    * @return array
    */
    public function delJobRecruiting()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->newsServiceClient->delJobRecruiting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 获取地区-省-市
    * @return array
    */
    public function getJobRecruitingArea()
    {
        $requireData = $this->request->all();
        $result = $this->websiteServiceClient->selectWebsiteArea($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 行业分类
    * @return array
    */
    public function getIndustry()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        $result = $this->newsServiceClient->getIndustry($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 职位分类
    * @return array
    */
    public function getPositionList()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getPositionList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 职位性质
    * @return array
    */
    public function getJobNature()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getJobNature($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 工作经验
    * @return array
    */
    public function getExperience()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getExperience($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 学历
    * @return array
    */
    public function getEducation()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getEducation($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 薪资
    * @return array
    */
    public function getSalary()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getSalary($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 语言
    * @return array
    */
    public function getLanguage()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getLanguage($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 语言-掌握能力
    * @return array
    */
    public function getLevel()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getLevel($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 公司规模
    * @return array
    */
    public function getCompanySize()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getCompanySize($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 公司性质
    * @return array
    */
    public function getCompanyNature()
    {
        $requireData = $this->request->all();
        $result = $this->newsServiceClient->getCompanyNature($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    /*
    *后端-招聘 职位审核
    * @return array
    */
    public function checkJobRecruiting()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'status' => 'required|integer|in:0,1,2',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => 'status不能为空',
                'status.integer' => 'status必须是整数',
                'status.in' => 'status必须是1,2,3中的一个'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if ($requireData['status'] == '2') {
            if (empty($requireData['refuse_reason'])) {
                return Result::error('请填写审核不通过原因');
            }
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->newsServiceClient->checkJobRecruiting($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    //202504084  审核状态
    public function updateGoodStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'status' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['type_id'] = Context::get("TypeId");
        $result = $this->newsServiceClient->updateGoodStatus($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateNoticeStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'status' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateNoticeStatus($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateComplaintStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'status' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateComplaintStatus($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateJobHuntingStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'status' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->newsServiceClient->updateJobHuntingStatus($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    //20250422  书刊音像
    public function getBookList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required|integer',
                'page_size' => 'required|integer'

            ],
            [
                'page.required' => '页码不能为空',
                'page.integer' => '页码必须是整数',
                'page_size.required' => '每页条数不能为空',
                'page_size.integer' => '每页条数必须是整数',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['type_id'] = Context::get("TypeId");
        $requireData['website_id'] = Context::get("SiteId");
        $result = $this->newsServiceClient->getBookList($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function addBook()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title' => 'required',
            ],
            [
                'title.required' => '书名不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['type_id'] = Context::get("TypeId");
        $requireData['website_id'] = Context::get("SiteId");
        $result = $this->newsServiceClient->addBook($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function deleteBook()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]

        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['type_id'] = Context::get("TypeId");
        $requireData['website_id'] = Context::get("SiteId");
        $result = $this->newsServiceClient->deleteBook($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateBook()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]

        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->newsServiceClient->updateBook($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function updateBookStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]

        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result = $this->newsServiceClient->updateBookStatus($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }
    public function getBookInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]

        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get('UserId');
        $result = $this->newsServiceClient->getBookInfo($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    //20250422  书刊音像
}
