<?php

declare(strict_types=1);

namespace App\Controller;

use App\JsonRpc\UserServiceInterface;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use App\Constants\ErrorCode;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use Hyperf\Context\Context;

/**
 * Class UserController
 * @package App\Controller
 */
//#[AutoController]
class UserController extends AbstractController
{
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;
    /**
     * @var UserServiceInterface
     */
    #[Inject]
    private $userServiceClient;

    public function createUser()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'user_name' => 'required', //登陆账号
                'type_id' => 'required', //用户类型
                'password' => 'required|min:6', //密码
                'confirm_password' => 'required',
                'real_name' => 'required',
                'role_id' => 'required',
                //                'mobile' =>'required'
            ],
            [
                'user_name.required' => '用户名不能为空',
                'password.required' => '密码不能为空',
                //                'email.email' => '请填写一个有效的邮箱',
                //                'mobile.required' => '手机号码必填',
                //                'mobile.telephone_number' => '请填写一个有效的手机号',
                'confirm_password.required' => "确认密码不能为空",
                'type_id.required' => "用户类型不能为空",
                'real_name.required' => "姓名不能为空",
                'password.min' => "密码长度不能低于6位数",
                'role_id.required' => "所属角色不能为空",
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        if ($requireData['password'] != $requireData['confirm_password']) {
            return Result::error("两次密码不一致");
        }
        $salt = rand(1, 999999);
        $requireData['salt'] = $salt;
        $loginIp = $this->request->getHeader('x-forwarded-for')[0] ?? $this->request->getHeader('x-real-ip')[0] ?? $this->request->getServerParams()['remote_addr'] ?? '0.0.0.0';
        $requireData['last_login_ip'] = $loginIp;
        $requireData['admin_id'] = Context::get("UserId");

        // $requireData['administrative_unit_id'] = isset($requireData['administrative_unit_arr_id']) && count($requireData['administrative_unit_arr_id'])>0 ?end($requireData['administrative_unit_arr_id']):0;
        // $requireData['administrative_unit_arr_id'] = isset($requireData['administrative_unit_arr_id']) && count($requireData['administrative_unit_arr_id'])>0?json_encode($requireData['administrative_unit_arr_id']):json_encode([]);

        $requireData['address_id'] = isset($requireData['address_arr_id']) && count($requireData['address_arr_id']) > 0 ? end($requireData['address_arr_id']) : 0;
        $requireData['address_arr_id'] = isset($requireData['address_arr_id']) && count($requireData['address_arr_id']) > 0 ? json_encode($requireData['address_arr_id']) : json_encode([]);

        $requireData['native_place_id'] = isset($requireData['native_place_arr_id']) && count($requireData['native_place_arr_id']) > 0 ? end($requireData['native_place_arr_id']) : 0;
        $requireData['native_place_arr_id'] = isset($requireData['native_place_arr_id']) && count($requireData['native_place_arr_id']) > 0 ? json_encode($requireData['native_place_arr_id']) : json_encode([]);

        $requireData['city_id'] = isset($requireData['city_arr_id']) && count($requireData['city_arr_id']) > 0 ? end($requireData['city_arr_id']) : 0;
        $requireData['city_arr_id'] = isset($requireData['city_arr_id']) && count($requireData['city_arr_id']) > 0 ? json_encode($requireData['city_arr_id']) : json_encode([]);

        $requireData['other'] = isset($requireData['other']) ? json_encode($requireData['other']) : '';
        $result =  $this->userServiceClient->createUser($requireData);
        return $result['code'] == 200 ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * @return array|void
     */
    public function resetPassword()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required',
                'password' => 'required',
            ],
            [
                'id.required' => "id不能为空",
                'password.required' => "密码不能为空",
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $salt = rand(1, 999999);
        $requireData['salt'] = $salt;
        $result =  $this->userServiceClient->resetPassword($requireData);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }
    /**
     * 更新用户
     * @return array
     */
    public function updateUser()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'user_name' => 'required', //登陆账号
                'type_id' => 'required', //用户类型
                'real_name' => 'required',
                //                'mobile' =>'required',
                'id' => 'required',
                'role_id' => 'required',
            ],
            [
                'user_name.required' => '用户名不能为空',
                //                'mobile.required' => '手机号码必填',
                'type_id.required' => "用户类型不能为空",
                'real_name.required' => "姓名不能为空",
                'id.required' => "id不能为空",
                'role_id.required' => "所属角色不能为空",
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $loginIp = $this->request->getHeader('x-forwarded-for')[0] ?? $this->request->getHeader('x-real-ip')[0] ?? $this->request->getServerParams()['remote_addr'] ?? '0.0.0.0';
        $requireData['last_login_ip'] = $loginIp;

        // $requireData['administrative_unit_id'] = isset($requireData['administrative_unit_arr_id']) && count($requireData['administrative_unit_arr_id'])>0 ?end($requireData['administrative_unit_arr_id']):0;
        $requireData['administrative_unit_arr_id'] = isset($requireData['administrative_unit_arr_id']) && count($requireData['administrative_unit_arr_id']) > 0 ? json_encode($requireData['administrative_unit_arr_id']) : json_encode([]);

        $requireData['address_id'] = isset($requireData['address_arr_id']) && count($requireData['address_arr_id']) > 0 ? end($requireData['address_arr_id']) : 0;
        $requireData['address_arr_id'] = isset($requireData['address_arr_id']) && count($requireData['address_arr_id']) > 0 ? json_encode($requireData['address_arr_id']) : json_encode([]);

        $requireData['native_place_id'] = isset($requireData['native_place_arr_id']) && count($requireData['native_place_arr_id']) > 0 ? end($requireData['native_place_arr_id']) : 0;
        $requireData['native_place_arr_id'] = isset($requireData['native_place_arr_id']) && count($requireData['native_place_arr_id']) > 0 ? json_encode($requireData['native_place_arr_id']) : json_encode([]);

        $requireData['city_id'] = isset($requireData['city_arr_id']) && count($requireData['city_arr_id']) > 0 ? end($requireData['city_arr_id']) : 0;
        $requireData['city_arr_id'] = isset($requireData['city_arr_id']) && count($requireData['city_arr_id']) > 0 ? json_encode($requireData['city_arr_id']) : json_encode([]);

        $requireData['other'] = isset($requireData['other']) ? json_encode($requireData['other']) : '';
        $requireData['admin_id'] = Context::get("UserId");

        $result =  $this->userServiceClient->updateUser($requireData);
        return $result ? Result::success($result['data']) : Result::error($result['message']);
    }

    /**
     * 获取用户信息内容
     * @return void
     */
    public function getUser()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required'
            ],
            [
                'id.required' => "id不能为空",
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result =  $this->userServiceClient->getUserInfo((int)$requireData['id']);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }
    /**
     * 获取用户信息
     * @return array|void
     */
    public function getUserInfo($id)
    {
        $result =  $this->userServiceClient->getUserInfo($id!=''?$id:(int)Context::get("UserId"));
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        $result['data']['website_id'] =   Context::get("SiteId");
        return Result::success($result['data']);
    }

    /**
     * 获取用户列表
     * @return array
     */
    public function getUserList()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page' => 'required',
                'pageSize' => 'required',
            ],
            [
                'page.required' => '页码不能为空',
                'pageSize.required' => '每页显示条数不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }

        $result =  $this->userServiceClient->getUserList($requireData);

        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }
    /**
     * 删除用户
     * @return array
     */
    //    public function delUser()
    //    {
    //        $requireData = $this->request->all();
    //        $validator = $this->validationFactory->make(
    //            $requireData,
    //            [
    //                'id' => 'required'
    //            ],
    //            [
    //                'id.required' => '用户ID不能为空'
    //            ]
    //        );
    //        if ($validator->fails()){
    //            $errorMessage = $validator->errors()->first();
    //            return Result::error($errorMessage);
    //        }
    //
    //        $result =  $this->userServiceClient->delUser($requireData['id']);
    //        if ($result['code'] != ErrorCode::SUCCESS) {
    //            return Result::error($result['message'],0,[]);
    //        }
    //        return Result::success($result['data']);
    //    }

    /**
     * 查看角色信息
     * @return array
     */
    public function roleInfo()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required'
            ],
            [
                'id.required' => '角色ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result =  $this->userServiceClient->roleInfo($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        $result['data']['rule'] = isset($result['data']['rule']) ? json_decode($result['data']['rule']) : [];
        return Result::success($result['data']);
    }
    /**
     * 验证用户是否存在
     * @return void
     */
    public function  verifyUserInfo()
    {
        $requireData = $this->request->all();
        var_dump($requireData);
        $result =  $this->userServiceClient->verifyUserInfo($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }
    /**
     * 角色列表
     * @return array|void
     */
    public function roleList()
    {
        $requireData = $this->request->all();
        $result =  $this->userServiceClient->roleList($requireData);
        if ($result['data']) {
            foreach ($result['data']['rows'] as $k => $v) {
                $result['data']['rows'][$k]['rule'] = $v['rule'] ? json_decode($v['rule']) : [];
            }
        }
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }

    /**
     * 添加角色
     * @return array
     */
    public function addRole()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'role_name' => 'required',
                'rule' => 'required',
                'remark' => 'required',
                'sort' => 'integer'
            ],
            [
                'role_name.required' => '角色名称不能为空',
                'rule.required' => '权限不能为空',
                'remark.required' => '职能描述不能为空',
                'sort.integer' => '排序必须是整数',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['rule'] = isset($requireData['rule']) && $requireData['rule'] ? json_encode($requireData['rule']) : [];
        $result =  $this->userServiceClient->addRole($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }

    /**
     * 删除角色
     * @return array
     */
    public function delRole()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id' => 'required'
            ],
            [
                'id.required' => '角色ID不能为空'
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result =  $this->userServiceClient->delRole($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }

    /**
     * 更新角色
     * @return array
     */
    public function updateRole()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'role_name' => 'required',
                'rule' => 'required',
                'remark' => 'required',
                'id' => 'required'
            ],
            [
                'id.required' => '角色ID不能为空',
                'role_name.required' => '角色名称不能为空',
                'rule.required' => '权限不能为空',
                'remark.required' => '职能描述不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $requireData['rule'] = isset($requireData['rule']) && $requireData['rule'] ? json_encode($requireData['rule']) : [];
        $result =  $this->userServiceClient->updateRole($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }


    /**
     * 修改密码
     * @return array
     */
    public function  changePassword()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'password' => 'required',
                'new_password' => 'required|min:6',
                'new_password1' => 'required|same:new_password',
            ],
            [
                'password.required' => '密码不能为空',
                'new_password1.required' => '确认密码不能为空',
                'new_password1.same' => '新密码和确认密码不一致',
                'new_password.min' => "密码长度不能低于6位数",
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        $result =  $this->userServiceClient->changePassword($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }

    public function upUserStatus()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'status' => 'required',
                'id' => 'required'
            ],
            [
                'id.required' => 'ID不能为空',
                'status.required' => '状态不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result =  $this->userServiceClient->upUserStatus($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }
    /**
     * 修改用户头像和昵称
     * @return array
     */
    public function  updateUserAvatarNickname()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                // 'nickname' =>'required',
                'avatar' => 'required',
                // 'real_name'=>'required',
            ],
            [
                'avatar.required' => '头像不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['user_id'] = Context::get("UserId");
        //过滤掉除user_id，nickname,avatar外的数据
        $requireData = array_filter($requireData, function ($key) {
            return in_array($key, ['user_id', 'nickname', 'avatar', 'real_name']);
        }, ARRAY_FILTER_USE_KEY);
        var_dump($requireData);
        $result =  $this->userServiceClient->updateUserAvatarNickname($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'], 0, []);
        }
        return Result::success($result['data']);
    }
}
